<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>KvantumPreviewBase</name>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="14"/>
        <source>Kvantum Preview</source>
        <translation>Kvantum Forhåndsvisning</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="29"/>
        <source>Push buttons</source>
        <translation>Trykknapper</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="77"/>
        <source>Toggle
push
button

with
height
greater
than
width</source>
        <translation>Skift
skubbe
knap

med
højde
større
end
bredde</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="95"/>
        <location filename="../../KvantumPreviewBase.ui" line="105"/>
        <source>Simple push button</source>
        <translation>Enkel trykknap</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="112"/>
        <location filename="../../KvantumPreviewBase.ui" line="128"/>
        <source>Toggle push button</source>
        <translation>Skift trykknap</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="141"/>
        <location filename="../../KvantumPreviewBase.ui" line="152"/>
        <source>Multi-line
 push button</source>
        <translation>Multi-linje
trykknap</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="160"/>
        <location filename="../../KvantumPreviewBase.ui" line="180"/>
        <source>Push button
with 32px folder icon</source>
        <translation>Trykknap
med 32px mappeikon</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="210"/>
        <location filename="../../KvantumPreviewBase.ui" line="224"/>
        <source>Default
push button</source>
        <translation>Standard
trykknap</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="266"/>
        <source>Flat buttons</source>
        <translation>Flade knapper</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="279"/>
        <source>Button Box</source>
        <translation>Knapboks</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="374"/>
        <source>Tool buttons</source>
        <translation>Værktøjsknapper</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="382"/>
        <location filename="../../KvantumPreviewBase.ui" line="459"/>
        <source>Simple toolbutton</source>
        <translation>Enkel værktøjsknap</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="466"/>
        <location filename="../../KvantumPreviewBase.ui" line="477"/>
        <source>Multi-line
toolbutton</source>
        <translation>Multi-linje
værktøjsknap</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="485"/>
        <location filename="../../KvantumPreviewBase.ui" line="508"/>
        <source>Toggle toolbutton
with an arrow</source>
        <translation>Skift værktøjsknap
med en pil</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="573"/>
        <location filename="../../KvantumPreviewBase.ui" line="597"/>
        <source>Toolbutton with 32px SVG icon
and text below</source>
        <translation>Værktøjsknap med 32px SVG ikon
og tekst nedenfor</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="618"/>
        <location filename="../../KvantumPreviewBase.ui" line="639"/>
        <source>Toolbutton with text below
and arrow</source>
        <translation>Værktøjsknap med tekst nedenfor
og pil</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="657"/>
        <location filename="../../KvantumPreviewBase.ui" line="678"/>
        <source>Toolbutton with icon at the side
and arrow</source>
        <translation>Værktøjsknap med ikon på siden
og pil</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="696"/>
        <location filename="../../KvantumPreviewBase.ui" line="723"/>
        <source>Toggle toolbutton with icon,
ordinary arrow
and dropdown menu arrow</source>
        <translation>Skift værktøjsknap med ikon,
almindelig pil
og rullemenu pil</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="528"/>
        <location filename="../../KvantumPreviewBase.ui" line="552"/>
        <source>Toolbutton with 32px PNG icon
beside text</source>
        <translation>Værktøjsknap med 32px PNG ikon
ved siden af tekst</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="366"/>
        <source>Push button with menu</source>
        <translation>Trykknap med menu</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="415"/>
        <source>Toggle
tool
button

with
height
greater
than
width</source>
        <translation>Skift
værktøjs
knap

til
højde
større
end
bredde</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="804"/>
        <source>Auto-raise</source>
        <translation>Automatisk hævning</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="825"/>
        <source>Radio/Check buttons</source>
        <translation>Radio/Check knapper</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="846"/>
        <location filename="../../KvantumPreviewBase.ui" line="859"/>
        <source>Simple radio button</source>
        <translation>Simpel radioknap</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="869"/>
        <location filename="../../KvantumPreviewBase.ui" line="880"/>
        <source>Multi-line
radio button</source>
        <translation>flerstrenget
Radio knap</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="891"/>
        <location filename="../../KvantumPreviewBase.ui" line="917"/>
        <source>Radio button with 32px SVG icon</source>
        <translation>Radio knap med 32px SVG ikon</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="940"/>
        <location filename="../../KvantumPreviewBase.ui" line="953"/>
        <source>Simple check box</source>
        <translation>Simpelt afkrydsningsfelt</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="963"/>
        <location filename="../../KvantumPreviewBase.ui" line="974"/>
        <source>Multi-line
check box</source>
        <translation>flerstrenget
afkrydsningsfelt</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="982"/>
        <location filename="../../KvantumPreviewBase.ui" line="995"/>
        <source>Tri-state check box</source>
        <translation>Tre tilstande afkrydsningsfelt</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1005"/>
        <location filename="../../KvantumPreviewBase.ui" line="1019"/>
        <source>Check box with icon</source>
        <translation>Afkrydsningsfelt med ikon</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1075"/>
        <source>Combos/Spins/Inputs</source>
        <translation>Kombinationer/Kørende/Valg</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1109"/>
        <location filename="../../KvantumPreviewBase.ui" line="1198"/>
        <location filename="../../KvantumPreviewBase.ui" line="1271"/>
        <location filename="../../KvantumPreviewBase.ui" line="1433"/>
        <location filename="../../KvantumPreviewBase.ui" line="1515"/>
        <location filename="../../KvantumPreviewBase.ui" line="1607"/>
        <source>Frameless (no difference)</source>
        <translation>Rammeløs (ingen forskel)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1120"/>
        <location filename="../../KvantumPreviewBase.ui" line="1159"/>
        <source>Standard combo box</source>
        <translation>Standard kombinationsboks</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1129"/>
        <location filename="../../KvantumPreviewBase.ui" line="1168"/>
        <source>Standard combo box 1</source>
        <translation>Standard kombinationsboks 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1137"/>
        <location filename="../../KvantumPreviewBase.ui" line="1176"/>
        <source>Standard combo box 2</source>
        <translation>Standard kombinationsboks 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1142"/>
        <location filename="../../KvantumPreviewBase.ui" line="1181"/>
        <source>Standard combo box 3</source>
        <translation>Standard kombinationsboks 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1147"/>
        <location filename="../../KvantumPreviewBase.ui" line="1186"/>
        <source>Standard combo box 4</source>
        <translation>Standard kombinationsboks 4</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1207"/>
        <location filename="../../KvantumPreviewBase.ui" line="1280"/>
        <location filename="../../KvantumPreviewBase.ui" line="1442"/>
        <location filename="../../KvantumPreviewBase.ui" line="1524"/>
        <source>Frameless 1</source>
        <translation>Rammeløs 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1216"/>
        <location filename="../../KvantumPreviewBase.ui" line="1289"/>
        <location filename="../../KvantumPreviewBase.ui" line="1451"/>
        <location filename="../../KvantumPreviewBase.ui" line="1533"/>
        <source>Frameless 2</source>
        <translation>Rammeløs 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1221"/>
        <location filename="../../KvantumPreviewBase.ui" line="1294"/>
        <location filename="../../KvantumPreviewBase.ui" line="1456"/>
        <location filename="../../KvantumPreviewBase.ui" line="1538"/>
        <source>Frameless 3</source>
        <translation>Rammeløs 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1226"/>
        <location filename="../../KvantumPreviewBase.ui" line="1299"/>
        <location filename="../../KvantumPreviewBase.ui" line="1461"/>
        <location filename="../../KvantumPreviewBase.ui" line="1543"/>
        <source>Frameless 4</source>
        <translation>Rammeløs 4</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1231"/>
        <location filename="../../KvantumPreviewBase.ui" line="1304"/>
        <location filename="../../KvantumPreviewBase.ui" line="1466"/>
        <location filename="../../KvantumPreviewBase.ui" line="1548"/>
        <source>Frameless 5</source>
        <translation>Rammeløs 5</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1236"/>
        <location filename="../../KvantumPreviewBase.ui" line="1309"/>
        <location filename="../../KvantumPreviewBase.ui" line="1471"/>
        <location filename="../../KvantumPreviewBase.ui" line="1553"/>
        <source>Frameless 6</source>
        <translation>Rammeløs 6</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1241"/>
        <location filename="../../KvantumPreviewBase.ui" line="1314"/>
        <location filename="../../KvantumPreviewBase.ui" line="1476"/>
        <location filename="../../KvantumPreviewBase.ui" line="1558"/>
        <source>Frameless 7</source>
        <translation>Rammeløs 7</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1246"/>
        <location filename="../../KvantumPreviewBase.ui" line="1319"/>
        <location filename="../../KvantumPreviewBase.ui" line="1481"/>
        <location filename="../../KvantumPreviewBase.ui" line="1563"/>
        <source>Frameless 8</source>
        <translation>Rammeløs 8</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1251"/>
        <location filename="../../KvantumPreviewBase.ui" line="1324"/>
        <location filename="../../KvantumPreviewBase.ui" line="1486"/>
        <location filename="../../KvantumPreviewBase.ui" line="1568"/>
        <source>Frameless 9</source>
        <translation>Rammeløs 9</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1256"/>
        <location filename="../../KvantumPreviewBase.ui" line="1329"/>
        <location filename="../../KvantumPreviewBase.ui" line="1491"/>
        <location filename="../../KvantumPreviewBase.ui" line="1573"/>
        <source>Frameless 10</source>
        <translation>Rammeløs 10</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1341"/>
        <location filename="../../KvantumPreviewBase.ui" line="1384"/>
        <source>Editable combo box</source>
        <translation>Redigerbar kombinationsboks</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1350"/>
        <location filename="../../KvantumPreviewBase.ui" line="1393"/>
        <source>Editable combo box 1</source>
        <translation>Redigerbar kombinationsboks 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1359"/>
        <location filename="../../KvantumPreviewBase.ui" line="1402"/>
        <source>Editable combo box 2</source>
        <translation>Redigerbar kombinationsboks 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1364"/>
        <location filename="../../KvantumPreviewBase.ui" line="1407"/>
        <source>Editable combo box 3</source>
        <translation>Redigerbar kombinationsboks 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1369"/>
        <location filename="../../KvantumPreviewBase.ui" line="1412"/>
        <source>Editable combo box 4</source>
        <translation>Redigerbar kombinationsboks 4</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1581"/>
        <location filename="../../KvantumPreviewBase.ui" line="1594"/>
        <source>Line-edit</source>
        <translation>Linjeredigering</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1683"/>
        <source>Sliders/Scrolls/Progress/Dial</source>
        <translation>Skydere/Scrolls/Status/Tast</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2240"/>
        <source>Containers</source>
        <translation>Containere</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2261"/>
        <source>Header 1</source>
        <translation>Header 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2270"/>
        <source>Header 2</source>
        <translation>Header 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2278"/>
        <source>Header 3</source>
        <translation>Header 3</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2283"/>
        <location filename="../../KvantumPreviewBase.ui" line="2381"/>
        <source>3rd Item</source>
        <translation>3. Genstand</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2291"/>
        <location filename="../../KvantumPreviewBase.ui" line="2369"/>
        <source>2nd Item</source>
        <translation>2. Genstand</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2295"/>
        <location filename="../../KvantumPreviewBase.ui" line="2331"/>
        <source>2nd Child</source>
        <translation>2. Underligende</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2300"/>
        <location filename="../../KvantumPreviewBase.ui" line="2336"/>
        <source>1st Child</source>
        <translation>1. Underligende</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2306"/>
        <location filename="../../KvantumPreviewBase.ui" line="2354"/>
        <source>1st Item</source>
        <translation>1. Punkt</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2326"/>
        <source>3rd Child</source>
        <translation>3. Underligende</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2624"/>
        <source>Row 0</source>
        <translation>Række 0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2629"/>
        <source>Row 1</source>
        <translation>Række 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2634"/>
        <source>Column 0</source>
        <translation>Kolonne 0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2642"/>
        <source>Column 1</source>
        <translation>Kolonne 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2647"/>
        <source>0-0</source>
        <translation>0-0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2655"/>
        <source>0-1</source>
        <translation>0-1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2663"/>
        <source>1-0</source>
        <translation>1-0</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2671"/>
        <source>1-1</source>
        <translation>1-1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2313"/>
        <location filename="../../KvantumPreviewBase.ui" line="2316"/>
        <source>Editable</source>
        <translation>Redigerbar</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2343"/>
        <source>Non-Editable</source>
        <translation>Ikke redigerbar</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2391"/>
        <source>Subwindow</source>
        <translation>Undervindue</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2438"/>
        <source>Panel frame</source>
        <translation>Panelramme</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2457"/>
        <location filename="../../KvantumPreviewBase.ui" line="2598"/>
        <location filename="../../KvantumPreviewBase.ui" line="2690"/>
        <source>GroupBox</source>
        <translation>Gruppeboks</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2477"/>
        <location filename="../../KvantumPreviewBase.ui" line="2529"/>
        <location filename="../../KvantumPreviewBase.ui" line="2823"/>
        <location filename="../../KvantumPreviewBase.ui" line="2900"/>
        <location filename="../../KvantumPreviewBase.ui" line="2948"/>
        <source>Tab 1</source>
        <translation>Tab 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2483"/>
        <source>Page 1 (disabled)</source>
        <translation>Side 1 (deaktiveret)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2495"/>
        <location filename="../../KvantumPreviewBase.ui" line="2543"/>
        <location filename="../../KvantumPreviewBase.ui" line="2841"/>
        <location filename="../../KvantumPreviewBase.ui" line="2914"/>
        <location filename="../../KvantumPreviewBase.ui" line="2962"/>
        <source>Tab 2</source>
        <translation>Tab 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2501"/>
        <source>Page 2 (disabled)</source>
        <translation>Side 2 (deaktiveret)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2535"/>
        <location filename="../../KvantumPreviewBase.ui" line="2728"/>
        <location filename="../../KvantumPreviewBase.ui" line="2783"/>
        <location filename="../../KvantumPreviewBase.ui" line="2906"/>
        <location filename="../../KvantumPreviewBase.ui" line="2954"/>
        <source>Page 1</source>
        <translation>Side 1</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2549"/>
        <location filename="../../KvantumPreviewBase.ui" line="2756"/>
        <location filename="../../KvantumPreviewBase.ui" line="2796"/>
        <location filename="../../KvantumPreviewBase.ui" line="2847"/>
        <location filename="../../KvantumPreviewBase.ui" line="2920"/>
        <location filename="../../KvantumPreviewBase.ui" line="2968"/>
        <source>Page 2</source>
        <translation>Side 2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2573"/>
        <source>Stack widget (page1)</source>
        <translation>Indbygget widget (side 1)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2587"/>
        <source>Stack Widget (page2)</source>
        <translation>Indbygget widget (side 2)</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2604"/>
        <source>Group box</source>
        <translation>Gruppeboks</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2682"/>
        <source>Dock Widget</source>
        <translation>Flydende Widget</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2699"/>
        <source>Checkable group box</source>
        <translation>Afkrydsningsbar gruppeboks</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2734"/>
        <source>Tool Box</source>
        <translation>Værktøjskasse</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2829"/>
        <source>Document mode</source>
        <translation>Dokumenttilstand</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2867"/>
        <source>Box frame</source>
        <translation>Kasseramme</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2997"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3001"/>
        <source>&amp;Submenu</source>
        <translation>&amp;Undermenu</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3021"/>
        <source>toolBar</source>
        <translation>Værktøjslinje</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3041"/>
        <source>toolBar_2</source>
        <translation>Værktøjslinje_2</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3063"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afslut</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3066"/>
        <source>Quit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3069"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3077"/>
        <source>&amp;Checkbox</source>
        <translation>&amp;Afkrydsningsfelt</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3090"/>
        <source>Toggle Layout</source>
        <translation>Skift layout</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3093"/>
        <source>Toggle layout direction</source>
        <translation>Skift layoutretning</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3105"/>
        <source>&amp;Doc Mode</source>
        <translation>&amp;Dokumenttilstand</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3108"/>
        <source>Show tabs in the document mode</source>
        <translation>Vis faner i dokumenttilstand</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3120"/>
        <source>Menu Button</source>
        <translation>Menu knap</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3123"/>
        <source>Hold pressed to show a menu</source>
        <translation>Hold nede for at vise en menu</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3134"/>
        <source>C&amp;heckbox</source>
        <translation>Af&amp;krydsningsfelt</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3142"/>
        <source>&amp;Radio button</source>
        <translation>&amp;Radio knap</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3150"/>
        <source>Radio &amp;button</source>
        <translation>Radio &amp;knap</translation>
    </message>
</context>
</TS>
